makeAgeDepthModelPlot <- function(ageDepthModel, 
                                  plot_time_gaps = TRUE, 
                                  plot_hiatuses = TRUE,
                                  dist_from_shore_km = NULL) {
  
  #' @title Plot Age-Depth-model
  #' 
  #' @description Plots age-depth model at different locations in the basin
  #' 
  #' @param ageDepthModel list generated by the function getAgeDepthModel
  #' @param plot_time_gaps Logical. Should gaps in time be highlighted?
  #' @param plot_hiatuses Logical. Should stratigraphic positions of hiatuses
  #' be highlighted?
  #' @param dist_from_shore_km location of age-depth model in the basin
  #' 
  #' @return a plot
  #' 
  
  
  #### Determine environment for plot title ####
  title_env = env_labels[which.min(abs(dist_from_shore_km-env_dist_from_shore_km))]
  
  #### Make empty plot ####
  plot(
    NULL,
    xlab = "Time [Ma]",
    ylab = "Height [m]",
    xlim = range(time_myr),
    ylim = range(ageDepthModel$heightRaw),
    type = "l",
    main = paste("Age-Depth Model ", dist_from_shore_km, " km from Shore (",title_env,")", sep = "")
  )
  
  #### Plot gaps ####
  if (plot_time_gaps) {
    for (i in seq_along(ageDepthModel$hiatusTimeList)) {
      rect(
        xleft = ageDepthModel$hiatusTimeList[[i]]$hiatusStart,
        xright = ageDepthModel$hiatusTimeList[[i]]$hiatusEnd,
        ybottom = 0,
        ytop = max(ageDepthModel$heightRaw),
        col = removed_time_col,
        lty = 0
      )
    }
  }
  
  #### plot age-depth model ####
  lines(
    x = time_myr, 
    y = ageDepthModel$heightMod,
    col = col_adm, 
    lwd = lwd_adm,
    lty = lty_adm
  )
  
  #### plot stratigraphic position of hiatuses ####
  if(plot_hiatuses){
    for (i in seq_along(ageDepthModel$hiatusHeights)){
      lines(
        y = rep(ageDepthModel$hiatusHeights[i],2),
        x = range(time_myr),
        col = hiatus_strat_col,
        lwd = hiatus_strat_lwd,
        lty = hiatus_strat_lty)
    }
  }
  
  
}
