prepare_download_trait_evo <- function(file,
                                       trait_series,
                                       trait_name,
                                       mode,
                                       ...) {
  #' @title prepare_download_trait
  #'
  #' @description generates csv file for download in trait evo tab
  #'
  #' @param file path of temp file
  #' @param trait_seriess output generated by function getEvolutionarySimulations
  #' @param trait_name character string, name of trait
  #' @param mode character string, mode of evolution
  #' @param ... numeric. parameters for modes of evolution
  #'  Entries 1-3 specify random walk.
  #'  Entries 4-5 specify stasis
  #'  Entries 6-9 specify Ornstein-Uhlenbeck
  #'
  #' @return a csv file
  #'
  #'


  ## Generate data frame
  # add time
  df <- data.frame(time_myr = trait_series[[1]]$time)
  # add trait values of all lineages
  for (i in seq_along(trait_series)) {
    df[[paste("lineage_", i, "_", trait_name, sep = "")]] <- trait_series[[i]]$val
  }

  ## write modes of evolution & parameters used
  metadata <- rep("", length(trait_series[[1]]$time))
  parameters <- list(...)
  if (mode == "Random Walk") {
    sigma <- parameters[[1]]
    mu <- parameters[[2]]
    x0 <- parameters[[3]]
    df[["mode_of_evolution"]] <- replace(metadata, 1, "Random Walk")

    df[["variability"]] <- replace(metadata, 1, sigma)
    df[["drift"]] <- replace(metadata, 1, mu)
    df[["initial_trait_value"]] <- replace(metadata, 1, x0)
  }
  if (mode == "Stasis") {
    mean <- parameters[[4]]
    variance <- parameters[[5]]

    df[["mode_of_evolution"]] <- replace(metadata, 1, "Stasis")

    df[["mean_trait_value"]] <- replace(metadata, 1, mean)
    df[["variance"]] <- replace(metadata, 1, variance)
  }

  if (mode == "Ornstein-Uhlenbeck") {
    mu <- parameters[[6]]
    theta <- parameters[[7]]
    sigma <- parameters[[8]]
    x0 <- parameters[[9]]

    df[["mode_of_evolution"]] <- replace(metadata, 1, "Ornstein-Uhlenbeck")

    df[["long_term_mean"]] <- replace(metadata, 1, mu)
    df[["pressure_of_selection"]] <- replace(metadata, 1, theta)
    df[["volatility"]] <- replace(metadata, 1, sigma)

    df[["initial_trait_value"]] <- replace(metadata, 1, x0)
  }

  ## add citation info
  df[["citation"]] <- replace(metadata, 1, citation_text)


  # generate file for download
  write.csv(df, file = file, row.names = TRUE)
}
